Crate linux_aio_tokio

Tokio Bindings for Linux Kernel AIO

This package provides an integration of Linux kernel-level asynchronous I/O to the Tokio platform.

Linux kernel-level asynchronous I/O is different from the Posix AIO library. Posix AIO is implemented using a pool of userland threads, which invoke regular, blocking system calls to perform file I/O. Linux kernel-level AIO, on the other hand, provides kernel-level asynchronous scheduling of I/O operations to the underlying block device.

Structs

Enums

Traits

Functions

  • Create new AIO context suitable for cross-threaded environment (tokio rt-threaded), backed by parking_lot Mutex. Automatically spawn background task, which polls eventfd with tokio::spawn.
  • Create new AIO context with nr number of threads
  • Create new AIO context suitable for single-threaded environment (tokio rt-core)

Type Aliases

  • AIO context suitable for cross-threaded environment (tokio rt-threaded), backed by parking_lot Mutex
  • AIO context handle suitable for cross-threaded environment (tokio rt-threaded), backed by parking_lot Mutex
  • AIO context suitable for cross-threaded environment (tokio rt-core)
  • AIO context handle suitable for single-threaded environment (tokio rt-core)