pub struct File { /* private fields */ }Expand description
AIO version of tokio File, to work through GenericAioContextHandle
Implementations
Sourceimpl File
impl File
Sourcepub async fn open(path: impl AsRef<Path>, is_sync: bool) -> Result<File>
pub async fn open(path: impl AsRef<Path>, is_sync: bool) -> Result<File>
Open the file. See tokio File::open
Sourcepub async fn create(path: impl AsRef<Path>, is_sync: bool) -> Result<File>
pub async fn create(path: impl AsRef<Path>, is_sync: bool) -> Result<File>
Open the file. See tokio File::create
Sourcepub async fn set_permissions(&self, perm: Permissions) -> Result<()>
pub async fn set_permissions(&self, perm: Permissions) -> Result<()>
Set file permissions. See tokio set_permissions
Sourcepub async fn read_at<M: RawMutex, A: IntrusiveAdapter<M, L>, L: DefaultLinkOps<Ops = A::LinkOps> + Default>(
&self,
aio_handle: &GenericAioContextHandle<M, A, L>,
offset: u64,
buffer: &mut LockedBuf,
len: u64,
flags: ReadFlags,
) -> Result<u64, AioCommandError>
pub async fn read_at<M: RawMutex, A: IntrusiveAdapter<M, L>, L: DefaultLinkOps<Ops = A::LinkOps> + Default>( &self, aio_handle: &GenericAioContextHandle<M, A, L>, offset: u64, buffer: &mut LockedBuf, len: u64, flags: ReadFlags, ) -> Result<u64, AioCommandError>
Read the file through AIO at offset to the buffer with provided flags.
See submit_request for more information
Sourcepub async fn write_at<M: RawMutex, A: IntrusiveAdapter<M, L>, L: DefaultLinkOps<Ops = A::LinkOps> + Default>(
&self,
aio_handle: &GenericAioContextHandle<M, A, L>,
offset: u64,
buffer: &LockedBuf,
len: u64,
flags: WriteFlags,
) -> Result<u64, AioCommandError>
pub async fn write_at<M: RawMutex, A: IntrusiveAdapter<M, L>, L: DefaultLinkOps<Ops = A::LinkOps> + Default>( &self, aio_handle: &GenericAioContextHandle<M, A, L>, offset: u64, buffer: &LockedBuf, len: u64, flags: WriteFlags, ) -> Result<u64, AioCommandError>
Write to the file through AIO at offset from the buffer with provided flags.
See submit_request for more information
Sourcepub async fn sync_all<M: RawMutex, A: IntrusiveAdapter<M, L>, L: DefaultLinkOps<Ops = A::LinkOps> + Default>(
&self,
aio_handle: &GenericAioContextHandle<M, A, L>,
) -> Result<(), AioCommandError>
pub async fn sync_all<M: RawMutex, A: IntrusiveAdapter<M, L>, L: DefaultLinkOps<Ops = A::LinkOps> + Default>( &self, aio_handle: &GenericAioContextHandle<M, A, L>, ) -> Result<(), AioCommandError>
Sync data and metadata through AIO
See submit_request for more information
Sourcepub async fn sync_data<M: RawMutex, A: IntrusiveAdapter<M, L>, L: DefaultLinkOps<Ops = A::LinkOps> + Default>(
&self,
aio_handle: &GenericAioContextHandle<M, A, L>,
) -> Result<(), AioCommandError>
pub async fn sync_data<M: RawMutex, A: IntrusiveAdapter<M, L>, L: DefaultLinkOps<Ops = A::LinkOps> + Default>( &self, aio_handle: &GenericAioContextHandle<M, A, L>, ) -> Result<(), AioCommandError>
Sync only data through AIO
See submit_request for more information